@@ -54,6 +54,16 @@ class SimpleStepperDriverV1:
         uint32 = struct.unpack(">L",uint32_full)
         return uint32[0]
 
+    def uint16_to_hex_string(self,uintArray):
+        hexStr=b''
+        for uint in uintArray:
+            hexStr+=uint.to_bytes(2, byteorder='big', signed=False)
+        return hexStr.hex()
+
+    def getUid(self):
+        rslt = self.client.read_holding_registers(40004,6,unit=4).registers
+        return self.uint16_to_hex_string(rslt)
+        
     def on(self):
         self.client.write_registers(40049+3,1,unit=4)
 
