@@ -4,13 +4,13 @@ import time
 
 
 ssd = SimpleStepperDriverV1(method='rtu',serialPort = '/dev/ttyACM0')
-
+print(ssd.getUid())
 # ssd.writeD0(True)
 # print(ssd.readA5(),ssd.readA4())
-ssd.on()
+# ssd.on()
 # ssd.on()
 # ssd.off()
-ssd.go_forward(steps_per_second=20)
+# ssd.go_forward(steps_per_second=20)
 
 
 # while(1):
